@@ -4,7 +4,7 @@ use Moo;
 use utf8;
 use feature qw( say );
 
-our $VERSION = '0.000048';
+our $VERSION = '0.000049';
 
 use App::perlimports           ();
 use App::perlimports::Config   ();
@@ -54,6 +54,18 @@ has _inplace_edit => (
     },
 );
 
+has _json => (
+    is      => 'ro',
+    isa     => Bool,
+    lazy    => 1,
+    default => sub {
+        my $self = shift;
+        return defined $self->_opts->json
+            ? $self->_opts->json
+            : 0;
+    },
+);
+
 has _lint => (
     is      => 'ro',
     isa     => Bool,
@@ -108,7 +120,7 @@ sub _build_args {
         [],
         [
             'config-file=s',
-            'Path to a perlimports config file. If this parameter is not supplied, we will look for a file called perlimports.toml or .perlimports.toml in the current directory and then look for a perlimports.toml in XDG_CONFIG_HOME (usually something like $HOME/perlimports/perlimports.toml). This behaviour can be disabled via --no-config-file as described below.'
+            'Path to a perlimports config file. If this parameter is not supplied, we will look for a file called perlimports.toml or .perlimports.toml in the current directory and then look for a perlimports.toml in XDG_CONFIG_HOME (usually something like $HOME/perlimports/perlimports.toml). This behaviour can be disabled via --no-config-file'
         ],
         [],
         [
@@ -142,6 +154,11 @@ sub _build_args {
             'Path to file listing regular expressions that matches modules to ignore. One per line.'
         ],
         [],
+        [
+            'json',
+            '(Experimental) Emit linting results as JSON rather than plain text'
+        ],
+        [],
         [
             'never-export-modules=s',
             'Comma-separated list of modules which do not export symbols.'
@@ -361,6 +378,11 @@ sub run {
         ]
         );
 
+    if ( $self->_json && !$self->_lint ) {
+        $logger->error('--json can only be used with --lint');
+        return 1;
+    }
+
     if ( $self->_lint && $self->_inplace_edit ) {
         $logger->error('Cannot lint if inplace edit has been enabled');
         return 1;
@@ -388,6 +410,7 @@ sub run {
         @{ $self->_config->never_export }
         ? ( never_export_modules => $self->_config->never_export )
         : (),
+        json                => $self->_json,
         lint                => $self->_lint,
         logger              => $logger,
         padding             => $self->_config->padding,
@@ -492,7 +515,7 @@ App::perlimports::CLI - CLI arg parsing for C<perlimports>
 
 =head1 VERSION
 
-version 0.000048
+version 0.000049
 
 =head1 DESCRIPTION
 
